Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(103)

Unified Diff: content/common/service_manager/child_connection.h

Issue 2844923002: Replace InterfaceRegistry on RenderFrameHostImpl with BinderRegistry (Closed)
Patch Set: . Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/service_manager/child_connection.h
diff --git a/content/common/service_manager/child_connection.h b/content/common/service_manager/child_connection.h
index 9fd5877aaf730de2798c6983622856ecd8b768c8..abeb58830156222afb212d7b5decbf4a5b0d8d60 100644
--- a/content/common/service_manager/child_connection.h
+++ b/content/common/service_manager/child_connection.h
@@ -30,11 +30,11 @@ namespace content {
class CONTENT_EXPORT ChildConnection {
public:
// Prepares a new child connection for a child process which will be
- // identified to the service manager as |name|. |instance_id| must be unique
- // among all child connections using the same |name|. |connector| is the
- // connector to use to establish the connection.
- ChildConnection(const std::string& name,
- const std::string& instance_id,
+ // identified to the service manager as |child_identity|. |child_identity|'s
+ // instance field must be unique among all child connections using the same
+ // service name. |connector| is the connector to use to establish the
+ // connection.
+ ChildConnection(const service_manager::Identity& child_identity,
mojo::edk::PendingProcessConnection* process_connection,
service_manager::Connector* connector,
scoped_refptr<base::SequencedTaskRunner> io_task_runner);
« no previous file with comments | « content/browser/webui/web_ui_mojo_browsertest.cc ('k') | content/common/service_manager/child_connection.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698